@@ -401,9 +401,9 @@ class WordPressManager {
         ];
         
         // Create backup first
-        if ($site['backup_target_id']) {
+        if ($site['backup_target_id'] || $site['preferred_backup_target_id']) {
             try {
-                $backupResult = $this->createBackup($siteId);
+                $backupResult = $this->createBackup($site);
                 $results['backup_results'] = $backupResult;
                 // Backup created successfully
             } catch (Exception $e) {
@@ -1433,6 +1433,8 @@ Options -Indexes
         $db = $mysql->getMySQLConnection();
         $db->exec("USE whp");
         
+        $targetId = null;
+        
         // Check if site has a preferred backup target
         if (!empty($site['preferred_backup_target_id'])) {
             // Verify the user has access to this target
@@ -1449,8 +1451,11 @@ Options -Indexes
             if ($target) {
                 $targetId = $target['id'];
                 error_log("WordPress Backup: Using preferred backup target '{$target['name']}' (ID: {$targetId}, Type: {$target['type']}) for user {$site['user']}");
-            } else {
-                // Fall back to any available backup target
+            }
+        }
+        
+        // If no preferred target or preferred target not accessible, fall back to any available backup target  
+        if (!$targetId) {
                 $stmt = $db->prepare("
                     SELECT id, name, type 
                     FROM backup_targets 
@@ -1469,9 +1474,8 @@ Options -Indexes
                     throw new Exception("No backup targets configured. Please configure a backup target in the Backups section first.");
                 }
                 
-                $targetId = $target['id'];
-                error_log("WordPress Backup: Using backup target '{$target['name']}' (ID: {$targetId}, Type: {$target['type']}) for user {$site['user']}");
-            }
+            $targetId = $target['id'];
+            error_log("WordPress Backup: Using backup target '{$target['name']}' (ID: {$targetId}, Type: {$target['type']}) for user {$site['user']}");
         }
         
         // Queue site backup (files)
